@@ -1,11 +1,12 @@
 /* ISC license. */
 
-#ifndef GCCATTRIBUTES_H
-#define GCCATTRIBUTES_H
+#ifndef SKALIBS_GCCATTRIBUTES_H
+#define SKALIBS_GCCATTRIBUTES_H
 
 #ifdef __GNUC__
 
 #define gccattr_noreturn __attribute__((__noreturn__))
+#define gccattr_returns_twice __attribute__((__returns_twice__))
 #define gccattr_noinline __attribute__((__noinline__))
 #define gccattr_inline __attribute__((__always_inline__))
 #define gccattr_const __attribute__((__const__))
@@ -31,6 +32,7 @@
 #else
 
 #define gccattr_noreturn
+#define gccattr_returns_twice
 #define gccattr_noinline
 #define gccattr_inline
 #define gccattr_const
@@ -44,18 +46,4 @@
 
 #endif
 
-#ifdef GCCATTR_COMPAT_0_22
-#define _a_noreturn gccattr_noreturn
-#define _a_noinline gccattr_noinline
-#define _a_inline gccattr_inline
-#define _a_const gccattr_const
-#define _a_unused gccattr_unused
-#define _a_used gccattr_used
-#define _a_weak gccattr_weak
-#define _a_aligned gccattr_aligned
-#define _a_malloc gccattr_malloc
-#define _a_pure gccattr_pure
-#define _a_deprecated gccattr_deprecated
-#endif
-
 #endif
